GP.eigen.value: Compute eigen values for the standard modified exponential squared correlation kernel.
Description
Compute eigen values for the standard modified exponential squared correlation kernel.
Usage
GP.eigen.value(poly_degree = 10, a = 1, b = 1, d = 2)
Value
A matrix represents a set of eigen functions evaluated at grid points.
The number of rows is equal to the number of grid points. The number of columns is choose(poly_degree+d,d), where d is the dimnension of the grid points.
Arguments
poly_degree
A positive integer number specifies the highest degree of Hermite polynomials. The default value is 10L.
a
A positive real number specifying the concentration parameter in the modified exponetial squared kernel. The larger value the more the GP concentrates around the center. The default value is 0.01.
b
A positive real number specifying the smoothness parameter in the modeified exponetial squared kernel. The smaller value the smoother the GP is. The default value is 1.0.
d
A positive integer number specifying the dimension of grid points.
Author
Jian Kang <jiankang@umich.edu>
Details
Compute eigen values of the standard modified exponential squared kernel on d-dimensional grids